@@ -29,7 +29,7 @@ def query_yes_no(question, default="yes"):
 
     while True:
         sys.stdout.write(question + prompt)
-        choice = input().lower()
+        choice = input().lower()  # nosec
         if default is not None and choice == '':
             return valid[default]
         if choice in valid:
